---
title: "README.md"
author: "Wilfrid Kendall"
date: "9 March 2016 then 13 January 2017"
output: html_document
---

This project re-works Clair Barnes' (2015) MSc dissertation. 
Here is the abstract from Clair's dissertation.

> Statistical methods are increasingly finding applications in new disciplines; one area in which
> interest in such approaches has increased in recent years is archaeology, and in particular, in
> archaeological studies of Anglo-Saxon England.
> 
> A question currently under consideration in this field is whether any evidence exists that
> buildings in settlements dated to the early Medieval period may have been planned according
> to a perpendicular grid system. Assessment of the features of a site of interest, and any
> spatial or angular patterns contained therein, has until now typically been carried out by
> visual appraisal of transcribed site plans.
> 
> We propose a method by which a JPEG image of an archaeological site of interest may be
> converted into a set of points representing the locations of post-holes that once formed part of
> the support of large structures such as walls, buildings and fences. Defining the orientation
> of the post-holes by the direction in which its nearest neighbour lies, we are able to test
> objectively whether there is any evidence that larger features share a common orientation,
> and to assess whether a similar grid orientation is shared globally across multiple regions of
> the grid, or found only locally in smaller regions.


# Necessary preparation
Here are the steps needed to prepare a `Kubuntu` computer system to run the resulting code.

## Preparation of `Kubuntu` environment
Working in the `bash` terminal:

```
please apt-get install libssl-dev
please apt-get install libcurl4-openssl-dev
please apt-get install libgeos++-dev
```

The [geos](https://trac.osgeo.org/geos/)
software suite is required by the `AS.preprocessing` package, 
in order to load the [rgeos](https://cran.r-project.org/web/packages/rgeos/index.html) package.


## Preparation of `R` packages
Install `devtools` package using, e.g., `Rstudio`.
Similarly install package `fpc`.
Then load three packages from Clair Barnes' [GitHub repositories](https://github.com/ClairBee/)
using the following `R` code.

```
library(devtools)
install_github("ClairBee/AS.circular")
install_github("ClairBee/AS.preprocessing")
install_github("ClairBee/AS.angles")
```

## Preparation of Genlis image
The initial image cleaning requires interactive input!
Carry out the following within `R`:
```
library(AS.preprocessing)
genlis <- import.map("Genlis.jpg", threshold = 0.2, plot = T)
get.scale(genlis)
```
responding to prompts appropriately:
```
> get.scale(genlis)
Is the highlighted object the map scale? (y/n) > n
[1] Please click on the scale marker...
```
Click on marker! A further response is required, this time numerical,
followed by affirming that one wishes to continue.
```
What is the length, in metres, represented by the map scale? > 10
Do you want to rescale the map coordinates now? > y
[1] New object 'rescaled' created containing rescaled raster.
```
Now proceeed with
```
genlis.NS <- get.NS.axis(rescaled)
```
responding again to prompts:
```
[1] Please click on the N-S marker...
# Click on marker!
```
Finally add information to data structure.
```
genlis <- NS.marked

save.features(genlis, "Genlis-Initial-Cleansing")
```
so that the `Rstudio` script can commence with 
```
genlis <- load.features("Genlis-Initial-Cleansing")
```

## Bibliography
Barnes, C. (2015). *Statistics in Anglo-Saxon Archaeology.* MSc dissertation, Department of Statistics, University of Warwick. 82 pp including 5 appendices.
